gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[GNUnet-SVN] [gnurl] 121/150: krb5: use nondeprecated functions


From: gnunet
Subject: [GNUnet-SVN] [gnurl] 121/150: krb5: use nondeprecated functions
Date: Fri, 30 Mar 2018 16:49:35 +0200

This is an automated email from the git hooks/post-receive script.

ng0 pushed a commit to branch master
in repository gnurl.

commit 612bc926f7b40b2867fe1a28cf686c2131c72110
Author: Marcel Raad <address@hidden>
AuthorDate: Sat Mar 3 20:25:24 2018 +0100

    krb5: use nondeprecated functions
    
    gss_seal/gss_unseal have been deprecated in favor of
    gss_wrap/gss_unwrap with GSS-API v2 from January 1997 [1]. The first
    version of "The Kerberos Version 5 GSS-API Mechanism" [2] from June
    1996 already says "GSS_Wrap() (formerly GSS_Seal())" and
    "GSS_Unwrap() (formerly GSS_Unseal())".
    
    Use the nondeprecated functions to avoid deprecation warnings.
    
    [1] https://tools.ietf.org/html/rfc2078
    [2] https://tools.ietf.org/html/rfc1964
    
    Closes https://github.com/curl/curl/pull/2356
---
 lib/krb5.c | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/lib/krb5.c b/lib/krb5.c
index 35a4ca0c2..8b5a24720 100644
--- a/lib/krb5.c
+++ b/lib/krb5.c
@@ -85,7 +85,7 @@ krb5_decode(void *app_data, void *buf, int len,
 
   enc.value = buf;
   enc.length = len;
-  maj = gss_unseal(&min, *context, &enc, &dec, NULL, NULL);
+  maj = gss_unwrap(&min, *context, &enc, &dec, NULL, NULL);
   if(maj != GSS_S_COMPLETE) {
     if(len >= 4)
       strcpy(buf, "599 ");
@@ -119,11 +119,11 @@ krb5_encode(void *app_data, const void *from, int length, 
int level, void **to)
   int len;
 
   /* NOTE that the cast is safe, neither of the krb5, gnu gss and heimdal
    * libraries modify the input buffer in gss_seal()
    */
   dec.value = (void *)from;
   dec.length = length;
-  maj = gss_seal(&min, *context,
+  maj = gss_wrap(&min, *context,
                  level == PROT_PRIVATE,
                  GSS_C_QOP_DEFAULT,
                  &dec, &state, &enc);
@@ -119,11 +119,11 @@ krb5_encode(void *app_data, const void *from, int length, 
 
   /* NOTE that the cast is safe, neither of the krb5, gnu gss and heimdal
-   * libraries modify the input buffer in gss_seal()
+   * libraries modify the input buffer in gss_wrap()
    */
   dec.value = (void *)from;

-- 
To stop receiving notification emails like this one, please contact
address@hidden



reply via email to

[Prev in Thread] Current Thread [Next in Thread]